@@ -229,7 +229,7 @@ def rbme_posterior_plot(
     ax[2].plot(diff_coefs, posterior_occs_marg, color='k')
     ax[2].set_xscale("log")
     ax[2].set_ylabel("Marginal posterior\noccupation", fontsize=fontsize)
-    ax[2].set_xlim((0.01, 100.0))
+    ax[2].set_xlim((np.min(diff_coefs), np.max(diff_coefs)))
     if truncate_y_axis:
         ax[2].set_ylim((0, posterior_occs_marg[diff_coefs>0.05].max()*2.0))
     else:
@@ -857,7 +857,7 @@ def lineplot_by_condition(
         for s in ['top', 'left', 'right']:
             axes[i].spines[s].set_visible(False)
         if i // nx == ny - 1:
-            ax.set_xlabel("Diff. coef. ($\mu$m$^{2}$ s$^{-1}$)", fontsize=fontsize)
+            axes[i].set_xlabel("Diff. coef. ($\mu$m$^{2}$ s$^{-1}$)", fontsize=fontsize)
 
     # Save
     plt.tight_layout()
